## 基于PN结测温原理的数字显示温度计

### 任务

根据前序作业所设计的基于PN结的温度传感器的模拟信号处理部分，参考STM32G030C8T6最小系统板电路原理，使用KiCAD自行设计一个可实现的电路图和PCB，并编写软件使之能满足以下技术要求。

### 技术要求

1、电路使用USB Type-C接口作为电源与通讯端口；

2、使用4位共阴LED数码管作为显示器件；

3、LM358运算放大器、电阻、电容、数码管用三极管等均使用SMD封装，测温用二/三极管使用XH-2A插座与系统连接；

4、电路板上必须保留单片机的SWD调试接口和Boot0外接下拉电阻；

5、电路开机后，LED数码管通过滚动显示自己的学号，并持续5秒，5秒后进入温度显示模式；

6、使用单片机ADC采集PN结温度传感电路生成的电压信号，经解算、校准后，使用LED数码管显示，每秒更新次数不小于2次；

7、单片机通过串口与计算机通信，使用CH340N作为USB-串口转接器，单片机以字符串形式，通过USB虚拟串口每秒至少发送2个温度数值；

8、PCB最大尺寸10*10cm，工艺要求见上文；

- PCB正面下方应标注你的姓名（拼音）和学号，单个字符高度3mm，宽度2mm；

- 在规定的时间节点前自行向PCB制造商提交PCB订单。

### 报告

报告应包含：

##### 1、完整的电路原理图

##### 2、PCB版图

##### 3、电路原理的描述（模拟电路原理描述，计算，minisys板的原理介绍）

##### 4、模拟电路部分的仿真结果

##### 5、单片机软件的框架结构及工作原理，部分关键性代码

##### 6、实验测试结果（温度可以使用工具箱里的NTC热敏电阻加万用板电阻档测出阻值再用NTC公式换算，具体计算方法见课程ppt《2.元器件的识别与选用》P27-29）

##### 7、作品的完整照片或视频和测试过程中的照片。



### 评分（总分50）

|     项目     | 分项           | 分值 | 要求                                                         |
| :----------: | -------------- | ---- | ------------------------------------------------------------ |
| 模拟电路设计 | 调理电路设计   | 6    | 报告中有调理电路传函计算                                     |
|              | 恒流源设计     | 4    | PN结正向激励电流的生成需要由恒流源提供，可通过实测或仿真证明 |
|              | 误差分析       | 2    | 报告中有测温实测数据及误差分析                               |
|  单片机设计  | 基本测温功能   | 5    | 包括模拟量采集、数据显示                                     |
|              | ADC原理分析    | 3    | ADC转换公式                                                  |
|              | 温度转换算法   | 2    | 电压-温度传函的推导过程                                      |
|              | 标定/拟合流程  | 3    | 有误差修正过程或算法                                         |
|     PCB      |                | 10   | 符合生产工艺要求和设计技术要求，布局合理，布线规范美观       |
|   数据通信   |                | 5    | 单片机能够以规定的速率发送温度数据，并在PC端显示             |
|     报告     | 格式           | 2    | 按照模板要求，公式、描述规范                                 |
|              | 原理描述       | 5    | 原理描述完整，图表清晰                                       |
|              | 测试过程与数据 | 3    | 测试过程有记录，有数据，有分析                               |





### 注意事项

*本作业最终的成果必须是PCB组件。*

提交时请将报告和视频/照片打包上传，大小不要超过10MB。报告请按照《综合实验报告模板》撰写，字数不少于2500字.

实验室提供的NTC热敏电阻用来进行温度标定。测试时，将PN结（三极管，注意防水处理）与NTC测温电阻一起放入水中，并使用万用表测得NTC电阻值，然后可以利用Excel，设计转换公式将电阻值转换为温度，作为标定参照。如有可能，尽量多测试几组温度数据，最低要求要有5组不同的温度数据。测试时，可使用一次性杯子装少许热水，测完加入冷水调整温度，如有条件也可以加冰块，拓展低温区数据。