## 基于STM32G0与SimpleFOC库的无刷直流电机驱动器

### 任务

使用STM32G0单片机配合DRV8300DPWR三相无刷电机驱动芯片及功率MOSFET，构建一个无刷直流电机（BLDC Motor）驱动器，并利用SimpleFOC库，完成对电机调速。最终提交的成果包括能够完成以下功能的电路板组件和设计报告。



### 技术要求

1. 基于STM32G030C8单片机，设计一款小功率无刷电机驱动器。
2. 该无刷电机驱动器可以满足以下要求：

- 采用12V直流供电（使用实验电源或者电源适配器）

- 理论输出相电流不小于3A

- 可通过一个电位器进行调速

- 可通过串口发送控制指令调整电机转速

- （选做）可采集电机相电流

- （选做）可实现无刷电机位置闭环，即通过指令或电位器，设定电机旋转角度

### 说明

- 实验室提供小功率无刷电机，但是需要自行测量极对数
- 电机具有霍尔传感器
- 电机控制算法可以使用SimpleFOC库，STM32的驱动可以使用Arduino框架
- DRV8300DPWR的参考资料：https://www.ti.com/cn/lit/ds/symlink/drv8300.pdf
- 功率MOSFET推荐的型号有：
  - CJQ4410
  - NCE9926
  - AP4008SD
  - AON3818



### 报告

报告应包含：

##### 1、完整的电路原理图

##### 2、PCB版图

##### 3、电路原理的描述（模拟电路原理描述，计算，minisys板的原理介绍）

##### 4、单片机软件的框架结构及工作原理，部分关键性代码

##### 5、实验测试结果

##### 6、作品的完整照片或视频和测试过程中的照片。



### 评分（总分60）

|     项目     | 分项                           | 分值 | 要求                                                         |
| :----------: | ------------------------------ | ---- | ------------------------------------------------------------ |
| 模拟电路设计 | 电机功率驱动的实现             | 8    | 报告中有相关部分的原理描述及参数计算                         |
|              | 相电流采集信号调理             | 2    | 报告中有电流采集调理电路原理描述及参数计算                   |
|  单片机设计  | SVPWM信号生成或simpleFOC的移植 | 10   | 原理、实现方法、定时器的编程                                 |
|              | ADC采集（电位器/相电流）       | 10   | 电压电流参数的计算、包括ADC转换公式、ADC采集程序流程         |
|              | 位置闭环控制                   | 5    | 原理、实现及算法描述清楚                                     |
|     PCB      |                                | 10   | 符合生产工艺要求和设计技术要求，布局合理，布线规范美观       |
|   数据通信   | 完成串口命令控制               | 5    | 单片机能够以接受串口发送的控制命令，并调整电机运行参数（转速、位置） |
|     报告     | 格式                           | 2    | 按照模板要求，公式、描述规范                                 |
|              | 原理描述                       | 5    | 原理描述完整，图表清晰                                       |
|              | 测试过程与数据                 | 3    | 测试过程有记录，有数据，有分析                               |



### 其他说明

实验用电机：NICHIBO MOTOR BLDC3640， 额定电压：12V， 空载电流：0.2A，最大空载额定转速：2000rpm，

实物如图：

<img src="./image/image-20240719190037776.png" alt="image-20240719190037776" style="zoom:58%;" />

定子引线，配套插座采用JST XHB-3A SMD（2.50mm间距）插座，KiCAD中可使用XH类似2.5mm/2.54mm脚距贴片插座代替：

![image-20240719190137833](./image/image-20240719190137833.png)

霍尔传感器引线，配套插座MXB-5A（1.5mm间距）SMD插座，KiCAD中无对应封装，需要自行设计封装，插座手册见器材清单中的淘宝链接：

<img src="./image/image-20240719190345201.png" alt="image-20240719190345201" style="zoom:80%;" />

霍尔传感器接线注意插座方向，反接会烧毁传感器。

定子引线线序可任意调换，只影响转动方向。



### 注意事项

*本作业最终的成果必须是PCB组件。*

提交时请将报告和视频/照片打包上传，大小不要超过10MB。报告请按照《综合实验报告模板》撰写，字数不少于2500字.